@@ -1,10 +1,11 @@
 # The COPYRIGHT file at the top level of this repository contains the full
 # copyright notices and license terms.
 from decimal import Decimal
-from trytond.pool import PoolMeta, Pool
-from trytond.modules.nereid_checkout.checkout import with_company_context
-from nereid import request, url_for, flash, redirect, route
+
+from nereid import flash, redirect, request, route, url_for
 from nereid.contrib.locale import make_lazy_gettext
+from trytond.modules.nereid_checkout.checkout import with_company_context
+from trytond.pool import Pool, PoolMeta
 
 _ = make_lazy_gettext('payment_gateway_paypal')
 
