@@ -1,8 +1,8 @@
 # The COPYRIGHT file at the top level of this repository contains the full
 # copyright notices and license terms.
-from trytond.pool import PoolMeta, Pool
 from nereid import redirect
 from nereid.contrib.locale import make_lazy_gettext
+from trytond.pool import Pool, PoolMeta
 
 _ = make_lazy_gettext('payment_gateway_paypal')
 
